# libdevpro
Módulo para exemplificar a construção de projetos Python no curso PyTools

Link para o curso [DevPro](https://pythonpro.com.br/)

Suportada versão 3 do Python

Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade de código:

```console
flake8
```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip
4. Integração contínua com GitHub Actions